@@ -1,6 +1,6 @@
 #' Check column names exist
 #'
-#' Internal function to check that supplied `data.frames` have the correct columns.
+#' Internal function to check that supplied `data.frames` have the correct columns and checks that sample labels are all unique.
 #' @param ddf.obj a ddf object from `mrds`
 #' @param segment.data segment data as defined in \code{\link{dsm}}
 #' @param observation.data observation data as defined in \code{\link{dsm}}
@@ -12,6 +12,7 @@
 check.cols <- function(ddf.obj, segment.data, observation.data, strip.width,
                        segment.area){
 
+  ## check that the columns are there
   checks <-list(segment.data = c("Effort","Sample.Label"),
                 observation.data = c("object","Sample.Label","size","distance"))
 
@@ -23,9 +24,15 @@ check.cols <- function(ddf.obj, segment.data, observation.data, strip.width,
                   paste(checks[[i]][!check.res],collapse="\", \""),
                   "\" not found in ", names(checks)[[i]],
                   ".\n  Check ?\"dsm-data\"."))
-
     }
   }
 
+  ## check that Sample.Label is unique
+  if(length(segment.data$Sample.Label)!=length(
+                            unique(segment.data$Sample.Label))){
+    warning("'Sample.Labels are non-unique in segment data!")
+  }
+
+
   invisible()
 }
