@@ -43,7 +43,7 @@ test_that("Density weighting",{
   mod1.w <- dsm(D~s(x,y), hn.model, mexdolphins$segdata, mexdolphins$obsdata,
                 weights=mod1$data$segment.area)
 
-  expect_equal(fitted(mod1),fitted(mod1.w))
+  expect_equal(fitted(mod1),fitted(mod1.w),tolerance=par.tol)
 
 
   # setting weights to 1 or another constant
@@ -54,12 +54,12 @@ test_that("Density weighting",{
   mod1.w2 <- dsm(D~s(x,y), hn.model, mexdolphins$segdata, mexdolphins$obsdata,
                 weights=rep(100,nrow(mexdolphins$segdata)))
 
-  expect_equal(fitted(mod1.w1),fitted(mod1.w2))
+  expect_equal(fitted(mod1.w1),fitted(mod1.w2),tolerance=par.tol)
 
   # scalar input of weights (same as weighting all as 1, or 10)
   mod1.ws1 <- dsm(D~s(x,y), hn.model, mexdolphins$segdata, mexdolphins$obsdata,
                 weights=1)
 
-  expect_equal(fitted(mod1.ws1),fitted(mod1.w2))
+  expect_equal(fitted(mod1.ws1),fitted(mod1.w2),tolerance=par.tol)
 
 })
